import * as tslib_1 from "tslib";
import { IgrCategoryAxisBase } from "./igr-category-axis-base";
import { CategoryAngleAxis } from "./CategoryAngleAxis";
/**
 * Represents a IgxDataChartComponent category angle axis. Useful for displaying radial categories.
*
* `IgrCategoryAngleAxis` represents a IgxDataChartComponent category angle axis. Useful for displaying radial categories
*
* ```ts
* <IgrDataChart
* 	ref={this.onChartRef}
* 	dataSource={this.state.dataSource}
* 	width="100%"
* 	height="100%" >
*
*     <IgrCategoryAngleAxis name="angleAxis" label="Department" />
*     <IgrNumericRadiusAxis name="radiusAxis" />
*
* </IgrDataChart>
* ```
*/
var IgrCategoryAngleAxis = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(IgrCategoryAngleAxis, _super);
    function IgrCategoryAngleAxis(props) {
        return _super.call(this, props) || this;
    }
    IgrCategoryAngleAxis.prototype.createImplementation = function () {
        return new CategoryAngleAxis();
    };
    Object.defineProperty(IgrCategoryAngleAxis.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryAngleAxis.prototype, "isAngular", {
        /**
         * Checks if the axis is of angular type
        */
        get: function () {
            return this.i.b0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryAngleAxis.prototype, "startAngleOffset", {
        /**
         * Indicates the angle in degress that the chart's 0th angle should be offset.
        *
        * Indicates the angle in degress that the chart's 0th angle should be offset.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}   >
        *
        *     <IgrCategoryAngleAxis name="angleAxis" startAngleOffset ={30} />
        *     <IgrNumericRadiusAxis name="radiusAxis" />
        *
        * </IgrDataChart>
        * ```
        */
        get: function () {
            return this.i.li;
        },
        set: function (v) {
            this.i.li = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryAngleAxis.prototype, "interval", {
        /**
         * Gets or sets the frequency of displayed labels.
         * The set value is a factor that determines which labels will be hidden. For example, an interval of 2 will display every other label.
        *
        * Gets or sets the frequency of displayed labels.The set value is a factor that determines which labels will be hidden.
        * For example, an interval of 2 will display every other label.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}   >
        *
        *     <IgrCategoryAngleAxis name="angleAxis" interval ={2} />
        *     <IgrNumericRadiusAxis name="radiusAxis" />
        *
        * </IgrDataChart>
        * ```
        */
        get: function () {
            return this.i.lf;
        },
        set: function (v) {
            this.i.lf = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryAngleAxis.prototype, "actualInterval", {
        /**
         * Gets the effective value for the current Interval.
        *
        * Gets the effective value for the current Interval.
        *
        * ```ts
        *
        * 	<IgrDataChart
        * 	ref={this.onChartRef}
        * 	dataSource={this.state.dataSource}
        * 	width="100%"
        * 	height="100%" >
        *
        *     <IgrCategoryAngleAxis name="angleAxis" label="Department" actualInterval={5} />
        *     <IgrNumericRadiusAxis name="radiusAxis" />
        *
        * </IgrDataChart>
        * ```
        */
        get: function () {
            return this.i.k9;
        },
        set: function (v) {
            this.i.k9 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryAngleAxis.prototype, "minorInterval", {
        /**
         * Gets or sets the frequency of displayed minor lines.
         * The set value is a factor that determines how the minor lines will be displayed.
        *
        * Gets or sets the frequency of displayed minor lines. The set value is a factor that determines how the minor lines will be displayed.
        *
        * ```ts
        *    <IgrDataChart
        * 	ref={this.onChartRef}
        * 	dataSource={this.state.dataSource}
        * 	width="100%"
        * 	height="100%" >
        *
        *     <IgrCategoryAngleAxis name="angleAxis" label="Department" minorInterval={5} />
        *     <IgrNumericRadiusAxis name="radiusAxis" />
        *
        * </IgrDataChart>
        * ```
        */
        get: function () {
            return this.i.lg;
        },
        set: function (v) {
            this.i.lg = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCategoryAngleAxis.prototype, "actualMinorInterval", {
        /**
         * Gets the effective value for the current MinorInterval.
        *
        * Get the effective value for the current minorInterval.
        *
        * ```ts
        *    <IgrDataChart
        * 	ref={this.onChartRef}
        * 	dataSource={this.state.dataSource}
        * 	width="100%"
        * 	height="100%" >
        *
        *     <IgrCategoryAngleAxis name="angleAxis" label="Department" actualMinorInterval={5} />
        *     <IgrNumericRadiusAxis name="radiusAxis" />
        *
        * </IgrDataChart>
        * ```
        */
        get: function () {
            return this.i.la;
        },
        set: function (v) {
            this.i.la = +v;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Gets the scaled angle in radians from the raw axis value.
    
    * @param unscaledAngle  * The raw axis value.
    */
    IgrCategoryAngleAxis.prototype.getScaledAngle = function (unscaledAngle) {
        var iv = this.i.getScaledAngle(unscaledAngle);
        return (iv);
    };
    /**
     * Gets the raw axis value from the scaled angle in radians.
    
    */
    IgrCategoryAngleAxis.prototype.getUnscaledAngle = function (scaledAngle) {
        var iv = this.i.getUnscaledAngle(scaledAngle);
        return (iv);
    };
    return IgrCategoryAngleAxis;
}(IgrCategoryAxisBase));
export { IgrCategoryAngleAxis };
//# sourceMappingURL=igr-category-angle-axis.js.map
