import { NumericScaleMode } from "./NumericScaleMode";
import { IgrNumericAxisBase, IIgrNumericAxisBaseProps } from "./igr-numeric-axis-base";
import { StraightNumericAxisBase } from "./StraightNumericAxisBase";
/**
 * Defines a set of basic methods and properties used to create a StraightNumeric axis.
*/
export declare abstract class IgrStraightNumericAxisBase<P extends IIgrStraightNumericAxisBaseProps = IIgrStraightNumericAxisBaseProps> extends IgrNumericAxisBase<P> {
    /**
                                 * @hidden
                                 */
    readonly i: StraightNumericAxisBase;
    constructor(props: P);
    /**
     * Gets or sets the axis scale mode.
    *
    * `scaleMode` can be used on numeric axes to allow scaling data values using built-in scalers. The available scalers are linear or logarithmic.
    *
    * ```ts
    * this.yAxis.scaleMode = NumericScaleMode.Logarithmic;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource} >
    *
    *     <IgrCategoryXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis"
    * 	scaleMode="logarithmic" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    scaleMode: NumericScaleMode;
}
export interface IIgrStraightNumericAxisBaseProps extends IIgrNumericAxisBaseProps {
    /**
     * Gets or sets the axis scale mode.
    *
    * `scaleMode` can be used on numeric axes to allow scaling data values using built-in scalers. The available scalers are linear or logarithmic.
    *
    * ```ts
    * this.yAxis.scaleMode = NumericScaleMode.Logarithmic;
    * ```
    *
    * ```ts
    *  <IgrDataChart
    *     dataSource={this.state.dataSource} >
    *
    *     <IgrCategoryXAxis name="xAxis" />
    *     <IgrNumericYAxis name="yAxis"
    * 	scaleMode="logarithmic" />
    *
    *     <IgrLineSeries
    *      name="series1"
    *     xAxisName="xAxis"
    * 	yAxisName="yAxis"
    * 	valueMemberPath="Value" />
    *  </IgrDataChart>
    * ```
    */
    scaleMode?: NumericScaleMode | string;
}
