import { IgrBrushScale, IIgrBrushScaleProps } from "./igr-brush-scale";
import { ValueBrushScale } from "./ValueBrushScale";
/**
 * Represents a brush scale that uses value-based brush selection.
*/
export declare class IgrValueBrushScale extends IgrBrushScale<IIgrValueBrushScaleProps> {
    protected createImplementation(): ValueBrushScale;
    /**
                                 * @hidden
                                 */
    readonly i: ValueBrushScale;
    constructor(props: IIgrValueBrushScaleProps);
    /**
     * Gets or sets the minimum value for this scale.
    */
    minimumValue: number;
    /**
     * Gets or sets the maximum value for this scale.
    */
    maximumValue: number;
    /**
     * Gets or sets whether the scale is logarithmic.
    */
    isLogarithmic: boolean;
    /**
     * Gets or sets the logarithm base for this scale.
    */
    logarithmBase: number;
    /**
     * Checks if the value brush scale is ready for usage in the chart
    */
    readonly isReady: boolean;
}
export interface IIgrValueBrushScaleProps extends IIgrBrushScaleProps {
    /**
     * Gets or sets the minimum value for this scale.
    */
    minimumValue?: number | string;
    /**
     * Gets or sets the maximum value for this scale.
    */
    maximumValue?: number | string;
    /**
     * Gets or sets whether the scale is logarithmic.
    */
    isLogarithmic?: boolean | string;
    /**
     * Gets or sets the logarithm base for this scale.
    */
    logarithmBase?: number | string;
}
